@@ -1,13 +1,11 @@
 from curl2swift.utils.dict_to_pretty_string import dict_to_pretty_string
-from curl2swift.parsing.parse_context import parse_context
+from curl2swift.parsing.get_request_properties import get_request_properties
 
 
 BASE_INDENT = " " * 4
 
 
-def create_request(curl_command, parser):
-    parsed_context = parse_context(curl_command, parser)
-
+def create_request(parsed_context):
     data_token = ''
     if parsed_context.data:
         data_token = '{}data=\'{}\',\n'\
